# Contributing

## Introduction

This library is a mildly-opinionated set of tweaks and extensions for the
Textual framework, put together from common tweaks and extras that I'm
finding I'm using in my own applications. As such I don't expect this to be
that useful to many people, and I'm also unlikely to roll with most PRs that
might be submitted (save for the odd typo or bugfix here and there).

If you do have an idea for something that might make sense for the library,
please consider hitting [the
discussions](https://github.com/davep/textual-enhanced/discussions) first
and having a chat with me about the idea.

However, I'm very happy to receive feedback, suggestions and bug reports.

## Feedback and suggestions

The best place for feedback and suggestions is [in
discussions](https://github.com/davep/textual-enhanced/discussions). If it
seems like something that makes sense for this library I'll turn it into an
issue from there.

Be sure to [have a look over the TODO
isues](https://github.com/davep/textual-enhanced/issues?q=is%3Aissue+is%3Aopen+label%3ATODO)
before leaving a request, it might be I'm already planning on implementing
whatever it is you're asking for.

## Bugs

Please report any bugs [as an
issue](https://github.com/davep/textual-enhanced/issues). When doing so,
please provide as much detail as possible, include things like library
version, operating system, some details of the environment, etc.

[//]: # (CONTRIBUTING.md ends here)
